@@ -1,10 +1,12 @@
 from . import fol
 from .prune import prune_equal_fanin, validate_pruning
 from .utils import collect_parameters, validate_data, validate_network
+from .relunn import get_reduced_model
 
 from ._version import __version__
 
 __all__ = [
+    'get_reduced_model',
     'fol',
     'prune_equal_fanin',
     'validate_pruning',
